@@ -12,9 +12,6 @@ from trytond.transaction import Transaction
 from trytond.tools import grouped_slice
 
 
-__all__ = ['Level', 'ProcessDunning', 'Letter']
-
-
 class Level(metaclass=PoolMeta):
     __name__ = 'account.dunning.level'
     print_on_letter = fields.Boolean('Print on Letter')
@@ -30,11 +27,9 @@ class ProcessDunning(metaclass=PoolMeta):
         cls._actions.append('print_letter')
 
     def do_print_letter(self, action):
-        pool = Pool()
-        Dunning = pool.get('account.dunning')
-        dunnings = Dunning.browse(Transaction().context['active_ids'])
+        dunnings = self.records
         ids = [d.id for d in dunnings
-            if d.state == 'done'
+            if d.state == 'waiting'
             and not d.blocked
             and d.party
             and d.level.print_on_letter]
@@ -57,14 +52,14 @@ class Letter(CompanyReport, metaclass=PoolMeta):
             return super(Letter, cls).execute(ids, data)
 
     @classmethod
-    def get_context(cls, records, data):
-        report_context = super(Letter, cls).get_context(records, data)
+    def get_context(cls, records, header, data):
+        report_context = super().get_context(records, header, data)
 
         pool = Pool()
         Date = pool.get('ir.date')
 
         dunnings = [d for d in records
-            if d.state == 'done'
+            if d.state == 'waiting'
             and not d.blocked
             and d.party]
         parties = list(set((d.party for d in dunnings)))
@@ -95,6 +90,8 @@ class Letter(CompanyReport, metaclass=PoolMeta):
     def get_party_letter():
 
         class PartyLetter(object, metaclass=PoolMeta):
+            __slots__ = ('dunnings', 'payments')
+
             def __init__(self, dunnings, payments):
                 self.dunnings = dunnings
                 self.payments = payments
@@ -126,7 +123,7 @@ class Letter(CompanyReport, metaclass=PoolMeta):
         payments = []
         for sub_parties in grouped_slice(parties):
             payments.append(Line.search([
-                        ('account.kind', '=', 'receivable'),
+                        ('account.type.receivable', '=', True),
                         ['OR',
                             ('debit', '<', 0),
                             ('credit', '>', 0),
