@@ -6,8 +6,10 @@ import trytond.tests.test_tryton
 from trytond.tests.test_tryton import ModuleTestCase
 from trytond.tests.test_tryton import doctest_teardown, doctest_checker
 
+from trytond.modules.company.tests import CompanyTestMixin
 
-class AccountDunningLetterTestCase(ModuleTestCase):
+
+class AccountDunningLetterTestCase(CompanyTestMixin, ModuleTestCase):
     'Test AccountDunningLetter module'
     module = 'account_dunning_letter'
 
